@@ -5,9 +5,9 @@ import pkgutil
 from lambda_toolkit.modules.utils import Utils
 from shutil import make_archive
 from shutil import rmtree
-from zipfile import ZipFile
 import sys
 import time
+import json
 
 class Project:
     def __init__(self, conf, kwargs):
@@ -73,7 +73,6 @@ class Project:
 
             self.log.info("Project '" + self.projectname + "' "
                           "[" + self.kwargs['runtime'] + "] has been created.")
-            self.conf.projects[self.projectname] = {}
             self.conf.projects[self.projectname]['deployed'] = False
             self.conf.projects[self.projectname]['runtime'] = self.kwargs['runtime']
 
@@ -110,15 +109,20 @@ class Project:
 
             if self.projectname in self.conf.projects:
                 self.log.info("Project '" + self.projectname + "' already exists in your configuration. Updating.")
-                self.conf.projects[self.projectname]['deployed'] = True
             else:
                 self._create_project_folders()
                 open(self.project_dir + "/__init__.py", 'a').close()
-                self.conf.projects[self.projectname] = {}
-                self.conf.projects[self.projectname]['deployed'] = True
-                self.conf.projects[self.projectname]['runtime'] = lambda_function['Configuration']['Runtime']
                 self.log.info("Project " + self.projectname + " imported.")
 
+            self.conf.projects[self.projectname]['deployed'] = True
+            self.conf.projects[self.projectname]['runtime'] = lambda_function['Configuration']['Runtime']
+            if 'Environment' in lambda_function['Configuration']:
+                if 'Variables' in lambda_function['Configuration']['Environment']:
+                    vars = lambda_function['Configuration']['Environment']['Variables']
+                    for v in vars:
+                        self.log.info("Importing lambda variable '" + v + "' with value '" + vars[v] + "'.")
+                        self.conf.projects[self.projectname]['variables'][v] = vars[v]
+
             import requests, zipfile
             if sys.version_info[0] == 3:
                 import io
@@ -150,24 +154,37 @@ class Project:
             replace = False
 
         try:
+
             if replace:
                 self.conf.get_boto3("lambda", "client").update_function_code(
                     FunctionName=self.projectname,
-                    ZipFile=open(self.project_zip_file, "rb").read()
+                    ZipFile=open(self.project_zip_file, "rb").read(),
                 )
                 self.log.info("Lambda project " + self.projectname + " was redeployed.")
             else:
+                if 'rolename' not in self.kwargs:
+                    self.log.warn("Project '" + self.project +
+                                  "' is new. The parameter --rolename is required. Skipping.")
+                    return self.conf
+
                 self.conf.get_boto3("lambda", "client").create_function(
                     FunctionName=self.projectname,
-                    Runtime=self.conf.projects[self.projectname]['runtime'],
+                    Runtime=self.kwargs['runtime'],
                     Role=self.kwargs['rolename'],
                     Handler='index.lambda_handler',
                     Description="Lambda project " + self.projectname + " deployed by lambda-proxy",
                     Code={
                         'ZipFile': open(self.project_zip_file, "rb").read()
+                    },
+                )
+
+            if 'variables' in self.conf.projects[self.projectname]:
+                self.conf.get_boto3("lambda", "client").update_function_configuration(
+                    FunctionName=self.projectname,
+                    Environment={
+                        'Variables': self.conf.projects[self.projectname]['variables']
                     }
                 )
-                self.log.info("Lambda project " + self.projectname + " was created and deployed.")
 
             self.conf.projects[self.projectname]['deployed'] = True
 
@@ -175,7 +192,6 @@ class Project:
             self.log.error(str(e))
             self.log.critical("Failed to deploy the lambda project.")
 
-        #os.remove(self.project_zip_file)
         return self.conf
 
     def undeploy_project(self):
@@ -192,7 +208,32 @@ class Project:
 
         return self.conf
 
+    def list_variables_project(self):
+        if self.projectname in self.conf.projects:
+            vars = self.conf.projects[self.projectname]['variables']
+            self.log.info("Lambda environment variables:")
+            for var in vars:
+                self.log.info("Variable: " + var + " Value: " + vars[var])
 
+            return self.conf
+
+        self.log.warn("Project does not exist")
+
+    def set_variable_project(self):
+        if self.projectname in self.conf.projects:
+            self.conf.projects[self.projectname]['variables'][self.kwargs['variable']] = self.kwargs['value']
+            self.log.info("Variable " + self.kwargs['variable'] + " now is: " + self.kwargs['value'])
+            return self.conf
+
+        self.log.warn("Project does not exist")
+
+    def unset_variable_project(self):
+        if self.projectname in self.conf.projects:
+            self.conf.projects[self.projectname]['variables'].pop(self.kwargs['variable'])
+            self.log.info("Variable " + self.kwargs['variable'] + " has been removed.")
+            return self.conf
+
+        self.log.warn("Project does not exist")
     def delete_all_regions_project(self):
         for reg in self.conf.aws_regions:
             self._update_new_region(reg)
@@ -289,13 +330,20 @@ class Project:
         if projectname in self.conf.proxies.keys():
             self.log.critical("You cannot act in a project with the same name of an existing proxy.")
         self.projectname = projectname
-        self.project_dir = os.path.join(os.path.expanduser(self.conf.sett['C_BASE_DIR']),
-                                        self.conf.sett['C_LAMBDAS_DIR'],
+        if self.projectname not in self.conf.projects:
+            self.conf.projects[self.projectname] = {}
+
+        if 'variables' not in self.conf.projects[self.projectname]:
+            self.log.debug("Creating project variable")
+            self.conf.projects[self.projectname]['variables'] = {}
+
+        self.project_dir = os.path.join(Utils.fixpath(self.conf.sett['C_BASE_DIR']),
+                                        Utils.fixpath(self.conf.sett['C_LAMBDAS_DIR']),
                                         self.conf.region, projectname)
-        self.project_zip_dir = os.path.join(os.path.expanduser(self.conf.sett['C_BASE_DIR']),
-                                            self.conf.sett['C_LAMBDAS_DIR'],
+        self.project_zip_dir = os.path.join(Utils.fixpath(self.conf.sett['C_BASE_DIR']),
+                                            Utils.fixpath(self.conf.sett['C_LAMBDAS_DIR']),
                                             self.conf.region,
-                                            self.conf.sett['C_LAMBDAS_ZIP_DIR'])
+                                            Utils.fixpath(self.conf.sett['C_LAMBDAS_ZIP_DIR']))
         self.project_zip_file = os.path.join(self.project_zip_dir, projectname + ".zip")
         self.project_zip_file_without_ext = os.path.join(self.project_zip_dir, projectname)
 
